/*
    Kopete Latex Plugin

    Copyright (c) 2004 by Duncan Mac-Vicar Prett   <duncan@kde.org>

    Kopete    (c) 2001-2004 by the Kopete developers  <kopete-devel@kde.org>

    *************************************************************************
    *                                                                       *
    * This program is free software; you can redistribute it and/or modify  *
    * it under the terms of the GNU General Public License as published by  *
    * the Free Software Foundation; either version 2 of the License, or     *
    * (at your option) any later version.                                   *
    *                                                                       *
    *************************************************************************
*/

#ifndef LatexPREFERENCES_H
#define LatexPREFERENCES_H

#include <tdecmodule.h>
#include <tqstring.h>

class LatexPrefsUI;
class TQListViewItem;

/**
  *@author Duncan Mac-Vicar Prett
  */

class LatexPreferences : public TDECModule
{
	TQ_OBJECT
  
public:

	LatexPreferences(TQWidget *parent = 0, const char* name = 0, const TQStringList &args = TQStringList());
	~LatexPreferences();

	virtual void save();
	virtual void load();

private:
	LatexPrefsUI *m_preferencesDialog;
private slots:
	void slotModified();
};

#endif
